4 ms·
Out of curiosity, I gave it a shot. I came out roughly 20% faster using python's inbuilt csv library. When I switched to pypy the csv library actually made it
by Twirrim 9y ago
Out of curiosity, I gave it a shot. I came out roughly 20% faster using python's inbuilt csv library.
When I switched to pypy the csv library actually made it nearly 2x slower than pypy using .split(delim)
- paulddraper 9y agoAnd you were using the pure Python CSV library, not the C one?
- nerdponx 9y agoOf course it's faster. Sorry, I wasn't clear. But good luck handling a tab in a quoted field, then.